@@ -225,7 +225,8 @@ class Queue(BaseJobsModel):
                 # and add it to the waiting queue
                 try:
                     job = Job.get_from_ident(job_ident)
-                    job.status.hset(STATUSES.WAITING)
+                    if job.status.hget() == STATUSES.DELAYED:
+                        job.status.hset(STATUSES.WAITING)
                     self.enqueue_job(job)
                 except Exception, e:
                     failures.append((job_ident, '%s' % e))
@@ -513,6 +514,13 @@ class Error(BaseJobsModel):
 
         return error
 
+    @classmethod
+    def collection_for_job(cls, job):
+        """
+        Helper to return a collection of errors for the given job
+        """
+        return cls.collection(job_model_repr=job.get_model_repr(), identifier=getattr(job, '_cached_identifier', job.identifier.hget()))
+
     @property
     def datetime(self):
         """
